# -*- coding: utf-8 -*-
"""
@File    : sh_stock.py
@Date    : 2023-07-18
上海证券交易所
"""

from stock_open_api.api.eastmoney import company
from stock_open_api.utils import json_util


def get_company_info(code):
    """
    上海证券交易所 公司 基本资料 | 发行相关
    https://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/Index?type=web&code=sh688092

    :param code: str eg: 688092

    :return:
    :rtype: dict

    >>> get_company_info('688627')
        {
          "公司名称": "杭州爱科科技股份有限公司",
          "英文名称": "Hangzhou IECHO Science & Technology Co., Ltd.",
          "A股代码": "688092",
          "A股简称": "爱科科技",
          "A股扩位简称": "爱科科技股份",
          "曾用名": null,
          "B股代码": null,
          "B股简称": null,
          "H股代码": null,
          "H股简称": null,
          "证券类别": "上交所科创板A股",
          "上市交易所": "上海证券交易所",
          "所属东财行业": "机械设备-专用设备-其他专用机械",
          "所属证监会行业": "制造业-专用设备制造业",
          "总经理": "方云科",
          "法人代表": "方云科",
          "董秘": "王鹏",
          "董事长": "方小卫",
          "证券事务代表": "戴凌胜,石鑫",
          "独立董事": "顾新建,徐赤,贾勇",
          "联系电话": "0571-86696861,0571-86609578",
          "电子信箱": "office@iechosoft.com",
          "传真": "0571-86698923",
          "公司网址": "www.iechosoft.com",
          "办公地址": "杭州市滨江区伟业路1号1幢",
          "注册地址": "杭州市滨江区伟业路1号1幢",
          "区域": "浙江",
          "邮政编码": "310000",
          "注册资本(元)": 5929.8731,
          "工商登记": "91330108770830908J",
          "雇员人数": 375,
          "管理人员人数": 12,
          "律师事务所": "北京中伦文德(杭州)律师事务所",
          "会计师事务所": "立信会计师事务所(特殊普通合伙)",
          "公司介绍": "杭州爱科科技股份有限公司(公司简称:爱科科技,股票代码:688092)是全球非金属行业智能切割一体化解决方案提供商,以科技创新为基础,面向全球提供智能切割解决方案、系统及服务。生产制造基地建筑面积逾60000平方米,拥有国内先进的设备生产线。公司致力于以高端智能装备核心技术推动我国工业转型升级,能够助力广告文印、汽车内饰、家居家纺、复合材料、纺织服装、办公自动化、鞋业、箱包等多种行业客户实现自动化、智能化、工业化生产。赋能企业转型升级,助力用户降本增效、节能降耗、产品创新,促进用户创造卓越价值。爱科秉承着“客户至上、以人为本”的核心价值观真诚服务每一位用户,公司在杭州建立总部,拥有丰云信息、爱科自动化、爱科机器人等3家子公司,并设立广州和郑州2家分公司及北京、上海、沈阳、长沙、成都等20+办事处,构建了完善的服务机制及网络。公司配备了强大的运维服务团队,7*24小时免费客服热线,为客户提供技术咨询、操作指导及售后服务“全生命周期”的全方位优质服务。目前爱科产品已覆盖亚洲、欧洲、非洲、北美洲、南美洲、大洋洲等100+国家和地区,助力各行业用户开创智能切割新篇章。爱科科技将坚持“以优质服务为宗旨、以客户需求为向导”的经营理念,以创新对话未来,重新定义智能切割新技术,让全球行业用户都能享受到来自爱科科技的优质产品服务。",
          "经营范围": "服务:自动化设备、智能装备及AI系统、计算机软硬件、网络信息工程、云服务平台、机械产品、机器人及控制系统、通信设备的技术开发、技术服务、技术咨询、成果转让;批发、零售:自动化设备,智能装备及AI系统,机器人及控制系统,普通机械,仪器仪表,电子计算机及配件;货物进出口(法律、行政法规禁止经营的项目除外,法律、行政法规限制经营的项目取得许可证后方可经营);生产:切割机;其他无需报经审批的一切合法项目(依法须经批准的项目,经相关部门批准后方可开展经营活动)",
          "成立日期": "2005-03-11",
          "上市日期": "2021-03-19",
          "发行市盈率(倍)": 26.78,
          "网上发行日期": "2021-03-10",
          "发行方式": "战略配售,网上定价发行,网下询价配售,市值申购,高管员工参与配售,保荐机构参与配售",
          "每股面值(元)": 1,
          "发行量(股)": 14789598,
          "每股发行价(元)": 19.11,
          "发行费用(元)": 48007700,
          "发行总市值(元)": 282629217.78,
          "募集资金净额(元)": 234621500,
          "首日开盘价(元)": 44,
          "首日收盘价(元)": 43.61,
          "首日换手率": 85.3421,
          "首日最高价(元)": 48.2,
          "网下配售中签率": 0.02166877,
          "定价中签率": 0.02889497
        }


    """
    return company.get_company_info("SH{}".format(code))


if __name__ == '__main__':
    print(json_util.format_json(get_company_info('688092')))
