# -*- coding: utf-8 -*-
"""
@File    : __init__.py.py
@Date    : 2023-07-17

上海证券交易所（上交所）

行情报表
http://www.sse.com.cn/market/price/report/

股票与存托凭证
http://www.sse.com.cn/assortment/stock/list/share/
"""